@@ -4,7 +4,7 @@
  */
 
 /* twpsk:  A gui application for PSK
- * Copyright (C) 1999-2006 Ted Williams WA0EIR 
+ * Copyright (C) 1999-2014 Ted Williams WA0EIR 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,7 +21,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
  * USA.
  *
- * Version: 3.0 - Jul 2008
+ * Version: 4.1 - Feb 2014
  */
 
 /*
@@ -108,18 +108,6 @@
 #define XmNnet             "net"
 #define XmCNet             "Net"
 
-#define XmNuseMixer        "useMixer"
-#define XmCUseMixer        "UseMixer"
-
-#define XmNmainVol         "mainVol"
-#define XmCMainVol         "MainVol"
-
-#define XmNoutVol          "outVol"
-#define XmCOutVol          "OutVol"
-
-#define XmNinVol           "inVol"
-#define XmCInVol           "InVol"
-
 #define XmNcall            "call"
 #define XmCCall            "Call"
 
@@ -132,9 +120,6 @@
 #define XmNptt             "ptt"
 #define XmCPtt             "Ptt"
 
-#define XmNmixerDev        "mixerDev"
-#define XmCMixerDev        "MixerDev"
-
 #define XmNcallBox         "callBox"
 #define XmCCallBox         "CallBox"
 
@@ -162,21 +147,21 @@ typedef struct
    float   txFreq;
    int     afc;
    int     net;
-   int     useMixer;
+#if 0
    int     mainVol;
    int     outVol;
    int     inVol;
+#endif
    String  call;
    int     zero;
-//   String  dspDev;
    String  serDev;
    int     ptt;
-   String  mixerDev;
    int     callBox;
    int     postamble;
    int     sampsize;
 } AppRes;
 
+#if 0
 typedef struct 
 {
    int recsrc;
@@ -186,16 +171,14 @@ typedef struct
    int mic;
    int useRec;
 } MixVals;
-
+#endif
 
 /*
  * Function Declarations
  */
 int  iniProc (char mode);
-int  init_mixer (void);
 void controlsBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
 void popupDiagCB (Widget w, XtPointer cdata, XtPointer cbs);
-void closeAudioDiagCB (Widget w, XtPointer cdata, XtPointer cbs);
 void closeVideoDiagCB (Widget w, XtPointer cdata, XtPointer cbs);
 void wideBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
 void mediunBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
@@ -219,7 +202,7 @@ void wfCB (Widget w, XtPointer cdata, XtPointer cbs);
 void wfDirCB (Widget w, XtPointer cdata, XtPointer cbs);
 void localCapsCB (Widget w, XtPointer cdata, XtPointer cbs);
 void openBtnCB (Widget w, XtPointer cdata, XtPointer cbs);
-void audioCB (Widget w, XtPointer cdata, XtPointer cbs);
+//void audioCB (Widget w, XtPointer cdata, XtPointer cbs);
 void chansCB (Widget w, XtPointer cdata, XtPointer cbs);
 void setLevel (int device, int level);
 void qpskCB (Widget w, XtPointer cdata, XtPointer cbs);
