@@ -1,5 +1,5 @@
 /* twpsk  - A gui application for PSK
- * Copyright (C) 1999-2006 Ted Williams WA0EIR
+ * Copyright (C) 1999-2014 Ted Williams WA0EIR
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,7 +16,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
  * USA.
  *
- * Version: 3.0 - Jul 2008
+ * Version: 4.1 - Feb 2014
  */
 
 const char *helpTopics[NUM_TOPICS] =
@@ -126,12 +126,6 @@ the main window, which you can select with a mouse click. All of these \
 buttons can also be \"pressed\" from the keyboard too, which is even faster \
 and easier. See the Accelerator Keys section for more information. \n\
 \n\
-Audio\n\
-The Audio button pops up a dialog box with controls to set the input \
-and output audio levels of the sound card. This button does not have \
-a corresponding button on the main window. See the Secondary Windows \
-section for more information. \n\
-\n\
 Video \n\
 The Video button pops up a dialog box to control the speed and brightness \
 of the Spectrum display. This button does not have a corresponding button \
@@ -554,8 +548,8 @@ seems to do a pretty good job. \n\
 /***** SECONDARY WINDOWS *****/
 
 "\n\
-There are several secondary windows in twpsk. Two of these (Audio and Video) \
-have controls that are \"set and forget\", so you pop up these when \
+There are several secondary windows in twpsk. One of these (Video) \
+has controls that are \"set and forget\", so you pop up these only when \
 needed. The other windows are Secondary Decoders that allow you to copy up \
 to 4 QSOs at once. \n\
 \n\
@@ -592,22 +586,6 @@ you quit twpsk, it saves the current location of all the secondary windows. \
 From now on, the secondary windows will pop up in the same location they \
 were when you last quit twpsk. \n\
 \n\
-Audio Window \n\
-The Audio window is display from the Audio button on the Controls menu. It \
-can also be displayed by the accelerator key, Ctrl-A. This window has three \
-slider controls and a Close button. \n\
-\n\
-The Main and Out sliders, and the Mic Gain on your rig, set the drive level \
-for your transmitter. DO NOT OVER DRIVE YOUR TRANSMITTER! This will cause \
-distortion and interference to nearby stations. \n\
-\n\
-The In slider sets the drive level to the sound card. Set the AF Gain on \
-your rig a normal level. Then adjust the Brightness and In control until \
-the display looks the way you like. \n\
-\n\
-Once these controls are set, edit the resource file, Twpsk, and insert these \
-values so they will automatically be set when you start the program. \n\
-\n\
 Video Window \n\
 This window has two slider controls and a Close button. Both sliders are \
 for the Spectrum/Waterfall display. The Display Speed sets the refresh \
@@ -805,8 +783,8 @@ text files that you can send. Notice that they can be sent by using their \
 Ctrl key too. (Ctrl-1, Ctrl-2, etc) \n\
 \n\
 Now click on the Controls button on the menu bar. Most of these buttons \
-are also on the interface. However, notice that Secondary decoder, \
-Video, and Audio dialogs can be called with control keys. \n\
+are also on the interface. However, notice that the Secondary decoders, \
+and Video dialogs can be called with control keys. \n\
 \n\
 Next, click on the Seek button in the main menu bar. You should now be \
 looking at the buttons to start and stop a seek. Their accelerator keys are \
