@@ -1,5 +1,5 @@
 /* twpsk  - A gui application for PSK
- * Copyright (C) 1999-2006 Ted Williams WA0EIR 
+ * Copyright (C) 1999-2014 Ted Williams WA0EIR 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,7 +16,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
  * USA.
  *
- * Version: 3.0 - Jul 2008
+ * Version: 4.1 - Feb 2014
  */
 
 #ifndef TWPSKWIDS_INCLUDED
@@ -61,7 +61,7 @@ class Wids {
       Widget mainForm;
       Widget   label1, menuBar, fileMenu, fileCas;
       Widget   controlsMenu, controlsCas;
-      Widget     audioBtn, videoBtn;
+      Widget     videoBtn;
       Widget     rxBtn, txBtn, tuneBtn, sep;
       Widget     broadBtn, mediumBtn, narrowBtn; 
       Widget     saBtn, wfBtn, wfDirTB, openBtn;
@@ -112,18 +112,6 @@ class Wids {
       Widget       txText;
       Widget       clrTxPopup;
       
-      Widget   audioDiag;
-      Widget     mixerLabel;
-      Widget     mixerFrame;
-      Widget       mixerForm;
-      Widget        mainLabel, mainScale;
-      Widget        outLabel, pcmScale;
-      Widget        inputLabel, inScale;
-      Widget     configLabel;
-      Widget     scFrame, scForm, scRC;
-      Widget        chansOM;
-      Widget     audioCloseBtn;
-
       Widget   videoDiag;
       Widget     videoLabel;
       Widget     videoFrame;
